

zetup.py
========



|image0| |image1| |image2| |image3|

.. |image0| image:: http://www.gnu.org/graphics/lgplv3-88x31.png
   :target: http://www.gnu.org/licenses/lgpl.html
.. |image1| image:: https://pypip.in/version/zetup/badge.svg
   :target: https://pypi.python.org/pypi/zetup
.. |image2| image:: https://pypip.in/py_versions/zetup/badge.svg
   :target: https://pypi.python.org/pypi/zetup
.. |image3| image:: https://travis-ci.org/userzimmermann/zetup.py.svg?branch=master
   :target: https://travis-ci.org/userzimmermann/zetup.py



Zimmermann's `Python <http://python.org>`__ package setup
---------------------------------------------------------



-  https://bitbucket.org/userzimmermann/zetup.py
-  https://github.com/userzimmermann/zetup.py
-  https://www.openhub.net/p/python-zetup

